@@ -38,7 +38,7 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.103';
+$VERSION = '0.105';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -69,7 +69,7 @@ sub newretrieve
 
   $tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL
 
-  say $tee "\n#Now in Sim::OPT::Report::newretrieve AND GOING TO CHECK THINGS.\n";
+  say $tee "\n#Now in Sim::OPT::Report::newretrieve.\n";
 
   my %simtitles = %main::simtitles;
   my %retrievedata = %main::retrievedata;
@@ -91,12 +91,12 @@ sub newretrieve
 
   my %dt = %{ $_[0] };
 
-  my %dirfiles = %{ $dt{dirfiles} }; #say $tee "HERE IN OPT SUB CALLBLOCK \%dirfiles: " . dump( \%dirfiles );
-  my $resfile = $dt{resfile}; #say $tee "HERE IN OPT SUB CALLBLOCK \$resfile: " . dump( $resfile );
-  my $flfile = $dt{flfile}; #say $tee "HERE IN OPT SUB CALLBLOCK \$flfile: " . dump( $flfile );
-  my %vehicles = %{ $dt{vehicles} }; #say $tee "HERE IN OPT SUB CALLBLOCK \%vehicles: " . dump( \%vehicles );
-  my $precious = $dt{precious}; #say $tee "HERE IN OPT SUB CALLBLOCK \$precious: " . dump( $precious );
-  my %inst = %{ $dt{inst} }; #say $tee "1 HERE IN OPT SUB CALLBLOCK \%inst: " . dump( \%inst );
+  my %dirfiles = %{ $dt{dirfiles} }; 
+  my $resfile = $dt{resfile}; 
+  my $flfile = $dt{flfile};
+  my %vehicles = %{ $dt{vehicles} }; 
+  my $precious = $dt{precious};
+  my %inst = %{ $dt{inst} }; 
   my %dowhat = %{ $dt{dowhat} };
   #my $csim = $dt{csim};
   my $postprocessga = $dt{postprocessga};
@@ -105,7 +105,7 @@ sub newretrieve
   #%inst = %{ Sim::OPT::washhash( \%inst ) }; say $tee "3 HERE IN OPT SUB CALLBLOCK \%onst: " . dump( \%onst );
   $inst_ref = Sim::OPT::filterinsts_wnames( \@{ $dirfiles{dones} } , \%inst );
   %inst = %{ $inst_ref }; # REASSIGNMENT!!!!!!
-  #say $tee "1 HERE IN OPT SUB CALLBLOCK AFTER  \%inst: " . dump( \%inst );
+
 
 
   my @simcases = @{ $dirfiles{simcases} }; ######
@@ -135,37 +135,37 @@ sub newretrieve
 
   my %d = %{ $dt{instance} };
 
-  my $countinstance = $d{instn}; #say $tee "HERE IN REPORT \$countinstance: " . dump( $countinstance );
+  my $countinstance = $d{instn}; #say $tee "HERE IN NEWRETRIEVE \$countinstance: " . dump( $countinstance );
 
-  my $countcase = $d{countcase}; #say $tee "HERE IN REPORT \$countcase: " . dump( $countcase );
-  my $countblock = $d{countblock}; #say $tee "HERE IN REPORT \$countblock: " . dump( $countblock );
-  my %datastruc = %{ $d{datastruc} }; #say $tee "HERE IN REPORT \%datastruc: " . dump( \%datastruc );
+  my $countcase = $d{countcase}; #say $tee "HERE IN NEWRETRIEVE \$countcase: " . dump( $countcase );
+  my $countblock = $d{countblock}; #say $tee "HERE IN NEWRETRIEVE \$countblock: " . dump( $countblock );
+  my %datastruc = %{ $d{datastruc} }; #say $tee "HERE IN NEWRETRIEVE \%datastruc: " . dump( \%datastruc );
   my @varnumbers = @{ $d{varnumbers} };
-  @varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee "HERE IN REPORT \@varnumbers: " . dump( @varnumbers );
+  @varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee "HERE IN NEWRETRIEVE \@varnumbers: " . dump( @varnumbers );
   my @miditers = @{ $d{miditers} };
-  @miditers = Sim::OPT::washn( @miditers ); #say $tee "HERE IN REPORT \@miditers: " . dump( @miditers );
-  my @sweeps = @{ $d{sweeps} }; #say $tee "HERE IN REPORT \@sweeps: " . dump( @sweeps );
+  @miditers = Sim::OPT::washn( @miditers ); #say $tee "HERE IN NEWRETRIEVE \@miditers: " . dump( @miditers );
+  my @sweeps = @{ $d{sweeps} }; #say $tee "HERE IN NEWRETRIEVE \@sweeps: " . dump( @sweeps );
 
-  my $direction = ${$dowhat{direction}}[$countcase][$countblock]; #say $tee "HERE IN REPORT \$direction: " . dump( $direction );
-  my $precomputed = $dowhat{precomputed}; #say $tee "HERE IN REPORT \$precomputed: " . dump( $precomputed );
-  my @takecolumns = @{ $dowhat{takecolumns} }; #say $tee "HERE IN REPORT \@takecolumns: " . dump( @takecolumns );
+  my $direction = ${$dowhat{direction}}[$countcase][$countblock]; #say $tee "HERE IN NEWRETRIEVE \$direction: " . dump( $direction );
+  my $precomputed = $dowhat{precomputed}; #say $tee "HERE IN NEWRETRIEVE \$precomputed: " . dump( $precomputed );
+  my @takecolumns = @{ $dowhat{takecolumns} }; #say $tee "HERE IN NEWRETRIEVE \@takecolumns: " . dump( @takecolumns );
 
   my $skipfile = $vals{skipfile};
 	my $skipsim = $vals{skipsim};
 	my $skipreport = $vals{skipreport};
   my %notecases;
 
-  my @winneritems = @{ $d{winneritems} }; #say $tee "HERE IN REPORT \@winneritems: " . dump( @winneritems );
-  my $countvar = $d{countvar}; #say $tee "HERE IN REPORT \$countvar: " . dump( $countvar );
-  my $countstep = $d{countstep}; #say $tee "HERE IN REPORT \$countstep: " . dump( $countstep );
+  my @winneritems = @{ $d{winneritems} }; #say $tee "HERE IN NEWRETRIEVE \@winneritems: " . dump( @winneritems );
+  my $countvar = $d{countvar}; #say $tee "HERE IN NEWRETRIEVE \$countvar: " . dump( $countvar );
+  my $countstep = $d{countstep}; #say $tee "HERE IN NEWRETRIEVE \$countstep: " . dump( $countstep );
 
-  my %to = %{ $d{to} }; #say $tee "HERE IN REPORT \%to: " . dump( %to );
+  my %to = %{ $d{to} }; #say $tee "HERE IN NEWRETRIEVE \%to: " . dump( %to );
   my $thisto = $to{to}; #say $tee "\$thisto: $thisto";
 
   my $cleanto = $inst{$thisto}; #say $tee "\$cleanto: $cleanto";
 
   my $origin = $d{origin};
-  my $from = $origin; #say $tee "HERE IN REPORT \$from: " . dump( $from );
+  my $from = $origin; #say $tee "HERE IN NEWRETRIEVE \$from: " . dump( $from );
   my $is = $d{is};
 
   my $fire = $d{fire};
@@ -293,7 +293,7 @@ ZZZ
 
     sub retrieve_stats_results
     {
-      my ( $result, $shortresfile, $shortresfile, $thisto, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ) = @_;
+      my ( $result, $resfile, $shortresfile, $thisto, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile, $semaphorego1, $semaphorego2, $semaphorestop1, $semaphorestop2, $textpattern, $afterlines ) = @_;
 
       my @retrdata = @$retrdata_ref;
       my $printthis;
@@ -963,7 +963,7 @@ sub newreport # This function retrieves the results of interest from the texts f
   my $direction = ${$dowhat{direction}}[$countcase][$countblock]; #NEW
   my $precomputed = $dowhat{precomputed};
   my @takecolumns = @{ $dowhat{takecolumns} }; #NEW
-  #say $tee "HERE IN REPORT \@_: " . dump( @_ );
+  #say $tee "HERE IN NEWREPORT \@_: " . dump( @_ );
 
   my ( @repfilemem, @linecontent, @convey );
   $" = " ";
@@ -997,7 +997,7 @@ sub newreport # This function retrieves the results of interest from the texts f
   }
   my $signalnewinstance = 1;
 
-  #say $tee "RELAUNCHED IN REPORT WITH INST " . dump( %inst );
+  #say $tee "RELAUNCHED IN NEWREPORT WITH INST " . dump( %inst );
   #say $tee "PROBING THE EXISTANCE OF $repfile";
 
   #say $tee "FIRE: $file";
@@ -1070,7 +1070,7 @@ sub newreport # This function retrieves the results of interest from the texts f
         foreach $ret_ref ( ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ) )
         {
           %retitem = %$ret_ref;
-          my $retfile = $retitem{retfile}; say $tee "IN REPORT 1 \$retfile $retfile";
+          my $retfile = $retitem{retfile}; say $tee "IN NEWREPORT 1 \$retfile $retfile";
           my $reporttitle = $retitem{reporttitle};
           my $themereport = $retitem{themereport};
           my $semaphorego = $retitem{semaphorego};
@@ -1094,7 +1094,7 @@ sub newreport # This function retrieves the results of interest from the texts f
 
           if ( -e $retfile )
           { say $tee "#Inspecting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", instance " . ($countinstance + 1) . ", file $retfile, to report $themereport." ;
-            say $tee "IN REPORT 2 \$retfile $retfile";
+            say $tee "IN NEWREPORT 2 \$retfile $retfile";
             open( RETFILE, "$retfile" ) or die( "$!" );
             my @lines = <RETFILE>;
             close RETFILE;
