@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.087'; # our $VERSION = '';
+$VERSION = '0.091'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.';
 
 #########################################################################################
@@ -235,9 +235,9 @@ sub sim
           if ( $tooltype eq "esp-r" )
           {
             my $launchline;
-            if ( ( -e "./*.res" ) or ( -e "./*.fl" ) or ( -e "./*.mfr" ) )
+            if ( ( -e "../tmp/*.res" ) or ( -e "../tmp/*.fl" ) or ( -e "../tmp/*.mfr" ) )
             {
-              $launchline = "rm ./*.res \n rm ./*.fl \n rm ./*.mfr \n cd $simelt/cfg/ \n bps -file $fileconfig -mode script";
+              $launchline = "rm ../tmp/*.res \n rm ../tmp/*.fl \n rm ../tmp/*.mfr \n cd $simelt/tmp/ \n bps -file $fileconfig -mode script";
             }
             else
             {
@@ -257,10 +257,10 @@ sub sim
               {
                 my $fileconfigroot = $fileconfig;
                 $fileconfigroot =~ s/\.cfg//;
-                $resfile = "$simelt/cfg/$fileconfigroot.res";
-                $flfile = "$simelt/cfg/$fileconfigroot.mfr";
+                $resfile = "$simelt/tmp/$fileconfigroot.res";
+                $flfile = "$simelt/tmp/$fileconfigroot.fl";
                 $shortresfile = "$fileconfigroot.res";
-                $shortflfile = "$fileconfigroot.mfr";
+                $shortflfile = "$fileconfigroot.fl";
               }
 
               open( SIMLIST, ">$simlist") or die( "$!" );
